@@ -617,6 +617,7 @@ opts_t opts_parse(unsigned int argc, char **argv)
 		{ "discard", 0, NULL, (int) 'X' },
 		{ "store-and-forward", 1, NULL, (int) 'U' },
 		{ "remote", 1, NULL, (int) 'R' },
+		{ "query", 1, NULL, (int) 'Q' },
 		{ "pidfile", 1, NULL, (int) 'P' },
 		{ "watchfd", 1, NULL, (int) 'd' },
 		{ "output", 1, NULL, (int) 'o' },
@@ -629,7 +630,7 @@ opts_t opts_parse(unsigned int argc, char **argv)
 	/*@+nullassign@ */
 	int option_index = 0;
 #endif				/* HAVE_GETOPT_LONG */
-	char *short_options = "hVpteIrab8kTA:fvnqcWD:s:gl0i:w:H:N:u:F:x:L:B:CEZ:SYKOXU:R:P:d:m:o:"
+	char *short_options = "hVpteIrab8kTA:fvnqcWD:s:gl0i:w:H:N:u:F:x:L:B:CEZ:SYKOXU:R:Q:P:d:m:o:"
 #ifdef ENABLE_DEBUGGING
 	    "!:"
 #endif
@@ -733,6 +734,8 @@ opts_t opts_parse(unsigned int argc, char **argv)
 			/*@fallthrough@ */
 		case 'R':
 			/*@fallthrough@ */
+		case 'Q':
+			/*@fallthrough@ */
 		case 'm':
 			if (!pv_getnum_check(optarg, PV_NUMTYPE_BARE_INTEGER)) {
 				/*@-mustfreefresh@ *//* see above */
@@ -993,6 +996,11 @@ opts_t opts_parse(unsigned int argc, char **argv)
 			break;
 		case 'R':
 			opts->remote = (pid_t) pv_getnum_count(optarg, false);
+			opts->action = PV_ACTION_REMOTE_CONTROL;
+			break;
+		case 'Q':
+			opts->query = (pid_t) pv_getnum_count(optarg, false);
+			opts->action = PV_ACTION_QUERY;
 			break;
 		case 'P':
 			opts->pidfile = pv_strdup(optarg);
@@ -1102,6 +1110,15 @@ opts_t opts_parse(unsigned int argc, char **argv)
 			/*@+mustfreefresh@ */
 		}
 
+		if (0 != opts->query) {
+			/*@-mustfreefresh@ *//* see above */
+			fprintf(stderr, "%s: %s\n", opts->program_name,
+				_("cannot use remote query when watching file descriptors"));
+			opts_free(opts);
+			return NULL;
+			/*@+mustfreefresh@ */
+		}
+
 		if (NULL != opts->output) {
 			/*@-mustfreefresh@ *//* see above */
 			fprintf(stderr, "%s: -o: %s\n", opts->program_name,
@@ -1138,6 +1155,16 @@ opts_t opts_parse(unsigned int argc, char **argv)
 #endif
 	}
 
+	/* Don't allow -R and -Q together. */
+	if ((0 != opts->remote) && (0 != opts->query)) {
+		/*@-mustfreefresh@ *//* see above */
+		fprintf(stderr, "%s: %s\n", opts->program_name,
+			_("cannot use remote control and remote query together"));
+		opts_free(opts);
+		return NULL;
+		/*@+mustfreefresh@ */
+	}
+
 	/*
 	 * Default options: -pterb
 	 */
@@ -1153,6 +1180,18 @@ opts_t opts_parse(unsigned int argc, char **argv)
 	if (opts->error_skip_block > 0 && 0 == opts->skip_errors)
 		opts->skip_errors = 1;
 
+	/*
+	 * Don't allow any non-option arguments with -R or -Q.
+	 */
+	if ((optind < (int) argc) && ((0 != opts->remote) || (0 != opts->query))) {
+		/*@-mustfreefresh@ *//* see above */
+		fprintf(stderr, "%s: %s: %s\n", opts->program_name, 0 != opts->remote ? "-R" : "-Q",
+			_("files cannot be specified with this option"));
+		opts_free(opts);
+		return NULL;
+		/*@+mustfreefresh@ */
+	}
+
 	/*
 	 * Store remaining command-line arguments.
 	 */
